@@ -8,7 +8,5 @@ then
     rm /etc/smartd_warning.sh
 fi
 
-rm -f /usr/share/smartmontools/drivedb.h.error \
-      /usr/share/smartmontools/drivedb.h.lastcheck \
-      /usr/share/smartmontools/drivedb.h.old
+rm -f /usr/share/smartmontools/drivedb.h.*
 
